use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text);

use utf8;

$result_trees{'ifnotinfo_exception'} = {
  'contents' => [],
  'type' => 'text_root'
};

$result_texis{'ifnotinfo_exception'} = '';


$result_texts{'ifnotinfo_exception'} = '';

$result_errors{'ifnotinfo_exception'} = [];


$result_floats{'ifnotinfo_exception'} = {};


1;
